@@ -19,6 +19,14 @@
 
 #define CURSES_IF_H
 
-extern void curses_game_init (void);
+#include "comm.h"
+
+enum refresh_amount {NONE, CURSOR, STATUSLINE, REFRESH_MAP, ALL};
+
+extern void curses_game_init (union conn_info *);
+extern void kill_curses (void);
+extern void c_draw_loc (const int);
+extern void c_read_key (union conn_info *);
+extern void do_refresh (const enum refresh_amount);
 
 #endif /* curses_if.h */
