@@ -55,7 +55,7 @@ parse_numbers (string, this_connect)
      const char **string;
      const int this_connect;
 {
-  int value, this_mask = 0;
+  int value, this_mask = 0, observer = 0;
   const char *ptr = *string;
   char *endptr;
   do
@@ -68,7 +68,7 @@ parse_numbers (string, this_connect)
 	      ptr++;
 	      continue;
 	    }
-	  else if (this_mask)
+	  else if (this_mask || observer)
 	    {
 	      *string = ptr+1;
 	      return this_mask;
@@ -79,10 +79,11 @@ parse_numbers (string, this_connect)
       ptr = endptr;
       if (value <= game_map.players && value > 0)
 	this_mask |= 1<<(value-1);
+      else if (value == 0)
+	observer = 1;
       else
 	die ("invalid player number");
-    }
-  while (*ptr != '\0');
+    } while (*ptr != '\0');
   die ("invalid player string: %s", string);
 }
 
@@ -109,8 +110,6 @@ parse_players (argc, argv, type, name, connect_mask, use_curses)
       int this_display_mask;
       ptr = argv[optind++];
       this_display_mask = parse_numbers (&ptr, this_connect);
-      if (this_display_mask == 0)
-	die ("invalid player string");
       if (this_display_mask & players_marked)
 	die ("player set multiple times");
 
