@@ -145,10 +145,8 @@ load_map (map_dir)
   game_map.bit_cross=0;
 
   game_map.size = game_map.width * game_map.height;
-  game_map.map = (map_val *) my_malloc (game_map.size *
-					sizeof (map_val));
-  game_map.capital = (Coord *) my_malloc (game_map.players *
-					  sizeof (Coord));
+  game_map.map = (map_val *) my_malloc (game_map.size * sizeof (map_val));
+  game_map.capital = (Coord *) my_malloc (game_map.players * sizeof (Coord));
 
   for (i = 0; i < game_map.size; i++)
     {
@@ -210,9 +208,8 @@ get_map_real_coord (loc)
 {
   if (!game_map.warped)
     {
-      /* Leftmost and upmost point are both zero, bottom is
-	 game_map.height minus one and rightmost point is
-	 game_map.width minus one.  */
+      /* Leftmost and upmost points are both zero, bottom is game_map.height
+	 minus one and rightmost point is game_map.width minus one.  */
       if (loc->x < 0 || loc->x >= game_map.width
 	  || loc->y < 0 || loc->y >= game_map.height)
 	{
@@ -328,8 +325,7 @@ check_surrounding (loc, me)
 
   for (i = 0; i < 8; i++)
     {
-      if ((get_map_val (add_coord (loc, round[i])) & MASK_PLAIN)
-	  == me)
+      if ((get_map_val (add_coord (loc, round[i])) & MASK_PLAIN) == me)
 	{
 	  /* Return ANY_CROSS, if all modes possible, else
 	     ONLY_GUERILLA, for guerilla.  */
@@ -373,8 +369,7 @@ check_cross (loc)
 	{
 	  /* Returns value ONLY_GUERILLA if only guerilla action is
 	     possible.  */
-	  return check_surrounding (loc, game_map.turn |
-				    MASK_OCCUPIED);
+	  return check_surrounding (loc, game_map.turn | MASK_OCCUPIED);
 	}
       /* Attack or defend action is possible.  */
       else if (game_map.modes & (MODE_ATT|MODE_DEF))
@@ -438,8 +433,7 @@ toggle_cross_nocheck (loc, check_result)
       if (check_result == ANY_CROSS)
 	set_modes ();
       else
-	game_map.modes = game_map.def_mode = game_map.sel_mode =
-	  MODE_GUE;
+	game_map.modes = game_map.def_mode = game_map.sel_mode = MODE_GUE;
       return 1;
     }
   return 0;
