@@ -36,6 +36,8 @@ typedef struct
   Coord *loc;
 } Action;
 
+extern void init_occupy (void);
+extern void defeat_players (const int, Action *);
 extern void action (int, Action *);
 
 #endif /* occupy.h */
