@@ -22,6 +22,7 @@
 
 #include "xinit.h"
 
-extern void event_loop (struct x_info_struct *);
+extern void x_turnchange (struct x_info_struct *);
+extern void x_event_handler (struct x_info_struct *);
 
 #endif /* xevent.h */
