@@ -29,12 +29,14 @@ enum button_class {
   ATT, DEF, GUE
 };
 
-extern void update_buttons (struct x_info_struct *, const int, char *);
-extern void draw_turn_win (struct x_info_struct *);
-extern void draw_map (struct x_info_struct *, int, int, int, int);
-extern void draw_effects (struct x_info_struct *, Action);
+extern void x_update_buttons (struct x_info_struct *);
+extern void x_draw_turn_win (struct x_info_struct *);
+extern void x_draw_map (struct x_info_struct *, Coord, Coord);
+extern void x_draw_effects (struct x_info_struct *, Action);
+extern void translate_box (struct x_info_struct *, int, int, int, int,
+			   Coord *, Coord *);
 extern Coord win_pos2map_coord (struct x_info_struct *, int, int);
-extern void create_end_win (struct x_info_struct *);
-extern void draw_end_win (struct x_info_struct *);
+extern void x_create_end_win (struct x_info_struct *);
+extern void x_draw_end_win (struct x_info_struct *);
 
 #endif /* xwin.h  */
